@@ -66,7 +66,9 @@ sub loadFromCodeClosure {
 	my ($lines) = 0;
 	my ($text) = "";
 
-	while ($_ = &{$closure}) {
+	# THANKS to "John R. Jackson" <jrj@gandalf.cc.purdue.edu> for
+	# grepping for unprotected while constructs.
+	while (defined($_ = &{$closure})) {
 		chomp;
 		my ($key,$value) = FAQ::OMatic::keyValue($_);
 		if ($key eq 'Author') {
@@ -105,7 +107,9 @@ sub loadFromCodeClosure {
 			"FAQ::OMatic::Part::loadFromCodeClosure was confused by this header in file $filename: \"$_\"");
 		}
 	}
-	while (($lines>0) and ($_ = &{$closure})) {
+	# THANKS to "John R. Jackson" <jrj@gandalf.cc.purdue.edu> for
+	# grepping for unprotected while constructs.
+	while (($lines>0) and defined($_ = &{$closure})) {
 		$text .= $_;
 		$lines--;
 	}
@@ -310,7 +314,7 @@ sub displayHTML {
 					'-params'=>$params,
 					'-changedParams'=>{'file'=>$filename,
 						'_target'=>$baglist[0]}),
-				gettext("Replace")." $baglist[0]<br>".gettext("with new upload")),
+				gettexta("Replace %0 with new upload", $baglist[0])),
 					'size'=>'edit'};
 		} elsif (scalar(@baglist)>1) {
 			push @rightEdits, {'text'=>FAQ::OMatic::button(
@@ -496,7 +500,7 @@ sub displayPartEditor {
 		if ($self->{'Text'} ne '') {
 			my @count = ($self->{'Text'} =~ m/\n/gs);
 			my $count = scalar(@count);
-			$rt .= gettext("Warning: file contents will <b>replace</b> previous text")                                                ." ($count lines).\n";
+			$rt .= gettext("Warning: file contents will <b>replace</b> previous text")." ($count lines).\n";
 		}
 	}
 
@@ -659,7 +663,7 @@ sub getBags() {
 
 	my $text = $self->{'Text'};
 	my @regexlist = ($text =~
-		m/(baginline:(\S*[^\s.,)\?!]))|(baglink:(\S*[^\s.,)\?!]))/gs);
+		m/(baginline:(\S*[^\s.,>)\?!]))|(baglink:(\S*[^\s.,>)\?!]))/gs);
 	# the above regexp will return 4*number of matches, one entry for
 	# each left parethesis.
 	# We actually want either the second or fourth item from each 4-tuple.
@@ -692,11 +696,12 @@ sub mergeDirectory {
 	return if ($dirhash{$filename});			# already done
 
 	my $item = new FAQ::OMatic::Item($filename);
+	my $headerpattern = gettext("Answers in this category:");
 	if ((defined $item->{'directoryHint'})
-		and ($self->{'Text'} =~ m/\n\nAnswers in this categ/)) {
+		and ($self->{'Text'} =~ m/\n\n$headerpattern/)) {
 		# Insert subcategories above "Answers in this category" header, if
 		# one exists.
-		$self->{'Text'} =~ s/(\n?\n\nAnswers in this categ)/\n\n<faqomatic:$filename>$&/s;
+		$self->{'Text'} =~ s/(\n?\n\n$headerpattern)/\n\n<faqomatic:$filename>$&/s;
 	} else {
 		# just tack on the end with all the other answers
 		$self->{'Text'} .= "\n<faqomatic:$filename>\n";
@@ -791,7 +796,8 @@ sub wrapLeftLines {
 	my @lines = split(/\n/, $text);
 	my @buffer = ();
 	my $rt = '';
-	while (my $line = shift @lines) {
+	my $line;
+	while (defined($line = shift @lines)) {
 		if ($line =~ m/^\s/) {
 			# a concrete line -- wrap prior buffer, pass concrete line
 			if (@buffer) {
